# This file is auto-generated by OpenAPI Python Client.
# Do not edit manually.

from http import HTTPStatus
from typing import Any

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.action_schema_out import ActionSchemaOut
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    account: str,
    identifier: str,
) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/external-resource/flush-elasticache/{account}/{identifier}",
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> ActionSchemaOut | HTTPValidationError | None:
    if response.status_code == 202:
        response_202 = ActionSchemaOut.from_dict(response.json())

        return response_202
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[ActionSchemaOut | HTTPValidationError]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """External Resource Flush Elasticache

     Flush an ElastiCache instance.

    This action initiates a flush of a specified ElastiCache instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        account=account,
        identifier=identifier,
    )

    with client as _client:
        response = _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


def sync(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
) -> ActionSchemaOut | HTTPValidationError | None:
    """External Resource Flush Elasticache

     Flush an ElastiCache instance.

    This action initiates a flush of a specified ElastiCache instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return sync_detailed(
        account=account,
        identifier=identifier,
        client=client,
    ).parsed


async def asyncio_detailed(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
) -> Response[ActionSchemaOut | HTTPValidationError]:
    """External Resource Flush Elasticache

     Flush an ElastiCache instance.

    This action initiates a flush of a specified ElastiCache instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ActionSchemaOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        account=account,
        identifier=identifier,
    )

    async with client as _client:
        response = await _client.request(
            **kwargs,
        )

    return _build_response(client=client, response=response)


async def asyncio(
    account: str,
    identifier: str,
    *,
    client: AuthenticatedClient | Client,
) -> ActionSchemaOut | HTTPValidationError | None:
    """External Resource Flush Elasticache

     Flush an ElastiCache instance.

    This action initiates a flush of a specified ElastiCache instance in a given AWS account.

    Args:
        account (str): AWS account name
        identifier (str): RDS instance identifier

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ActionSchemaOut, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            account=account,
            identifier=identifier,
            client=client,
        )
    ).parsed


from typing import Annotated

import typer

app = typer.Typer()


@app.command(
    help="""Flush an ElastiCache instance.

This action initiates a flush of a specified ElastiCache instance in a given AWS account.""",
    rich_help_panel="Actions",
)
def external_resource_flush_elasticache(
    ctx: typer.Context,
    account: Annotated[str, typer.Option(help="AWS account name", show_default=False)],
    identifier: Annotated[
        str, typer.Option(help="RDS instance identifier", show_default=False)
    ],
) -> None:
    result = sync(account=account, identifier=identifier, client=ctx.obj["client"])
    if "formatter" in ctx.obj and result is not None:
        output: Any = result
        if isinstance(result, list):
            output = [
                item.to_dict() if hasattr(item, "to_dict") else item for item in result
            ]
        elif hasattr(result, "to_dict"):
            output = result.to_dict()
        ctx.obj["formatter"](output)
